import type { PluginOption } from 'vite'
import { createHtmlPlugin } from 'vite-plugin-html'

import { defaultSettings } from '../../../../config'
import cdnModules from '../cdn'

const { cdn, system } = defaultSettings

const startLoadingCss = system.appInit.loading ? [ '/css/default.css' ] : []

export function configHtmlPlugin(env: ViteEnv, isBuild: boolean) {
  const htmlPlugin: PluginOption[] = createHtmlPlugin({
    minify: isBuild,
    inject: {
      // Inject data into ejs template
      data: {
        VUE_APP_TITLE: system.title,
        injectVlogScript: env.VITE_USE_V_CONSOLE
          ? `<script src="https://unpkg.com/vconsole@latest/dist/vconsole.min.js"></script><script>var vConsole = new window.VConsole();</script>`
          : '',
        injectAppContent: system.appInit.loading
          ? `<div class="gx-toast-loading"><div class="gx-toast-loading-cont"><span class="gx-toast-svg"><svg class="van-loading__circular" viewBox="25 25 50 50"><circle cx="50" cy="50" r="20" fill="none"></circle></svg></span><span class="gx-toast-svg-text">${system.appInit.loading?.text}</span></div></div>`
          : '',
        injectScript: cdn.use && isBuild ? cdnModules.map(e => e.js).filter(el => el) : [],
        injectLink: cdn.use && isBuild
          ? cdnModules.map(e => e.css).filter(el => el).concat(startLoadingCss as string[])
          : startLoadingCss
      }
    }
  })
  return htmlPlugin
}
