import Mockjs from 'mockjs'
import { permissions } from '../permissions'
import { handleRandomImage, getMobile } from '../../utils/util'
import userIds from './id'

const admin = [ 1, 2 ]

export interface RolesInfo {
  roleId: number;
  roleKey: string;
  roleName: string;
  status: string;
}

export interface UserList {
  id: number;
  name: string;
}

export const accessTokens = {
  gx12358: 'gx-accessToken',
  admin: 'admin-accessToken',
  editor: 'editor-accessToken',
  no_editor: 'test-accessToken'
}

export const accounts = {
  admin: 'gx.design',
  gx12358: 'aa123456',
  editor: 'gx.design',
  no_editor: 'gx.design'
}

export const rolesInfo: RolesInfo[] = [
  {
    roleId: 1,
    roleKey: 'gx-admin',
    roleName: 'gx12358-超级管理员',
    status: '0'
  },
  {
    roleId: 2,
    roleKey: 'admin',
    roleName: '超级管理员',
    status: '0'
  },
  {
    roleId: 3,
    roleKey: 'editor',
    roleName: '编辑人员',
    status: '0'
  }
]

export const tokenAccount = {
  '1': accessTokens.gx12358,
  '2': accessTokens.admin,
  '3': accessTokens.editor,
  '4': accessTokens.no_editor
}

const rolesInfoAccount = {
  '1': rolesInfo.filter(item => [ 1 ].includes(item.roleId)),
  '2': rolesInfo.filter(item => [ 2 ].includes(item.roleId)),
  '3': rolesInfo.filter(item => [ 3 ].includes(item.roleId)),
  '4': rolesInfo.filter(item => [ 3 ].includes(item.roleId))
}

export const defaultUser = (id = 2) => ({
  permissions: permissions[String(id)],
  roles: rolesInfoAccount[String(id)].map(item => item.roleKey),
  user: {
    userId: Number(id),
    admin: admin.includes(Number(id)),
    roles: rolesInfoAccount[String(id)],
    roleIds: rolesInfoAccount[String(id)].map(item => item.roleId),
    nickName: Mockjs.Random.name(),
    avatar: handleRandomImage(100, 100),
    address: Mockjs.Random.city(),
    email: 'gx12358@gmail.com',
    phonenumber: getMobile(),
    remark: Mockjs.Random.paragraph(1),
    tags: Array.from({ length: Mockjs.Random.integer(4, 8) }).map(_ => Mockjs.Random.word(1)).join(),
    userName: Object.keys(accessTokens).find(el => tokenAccount[String(id)] === accessTokens[el])
  } as Partial<UserDetails>
})

export const otherAccountList: UserList[] = [ '付小小', '曲丽丽', '林东东', '周星星', '吴加好', '朱偏右', '鱼酱', '乐哥', '谭小仪', '仲尼' ]
  .map((name, key) => {
    return {
      id: key + 1,
      name
    }
  })

export const userList: UserInfo[] = userIds.map(item => defaultUser(item.id)) as unknown as UserInfo[]
