import type { Router } from 'vue-router'
import { defaultSettings } from '@gx-config'

const { loginInterception, routesWhiteList } = defaultSettings.system

export function createPermissionGuard(router: Router) {
  const userStore = useStoreUser()

  router.beforeEach(async (to, _, next) => {
    if (loginInterception) {
      const token = userStore.accessToken
      if (routesWhiteList.includes(to.path)) {
        if (token) {
          next({ path: '/', replace: true })
        }
        next()
        return
      }
      if (!token) {
        userStore.resetPermissions()
        next({ path: '/user/login', replace: true })
        return
      }

      const hasUserId = userStore.userInfo.userId

      if (hasUserId) {
        next()
        return
      }

      const status = await userStore.checkUserPremission()
      if (status !== 1) {
        userStore.resetPermissions()
        next({ path: '/user/login', replace: true })
        return
      }
    }
    next()
  })
}
