import BasicLayout from '@/layout/BasicLayout/index.vue'
import UserLayout from '@/layout/UserLayout/index.vue'

// import.meta.globEager() 直接引入所有的模块 Vite 独有的功能
const modules = import.meta.glob('./modules/**/*.ts', { eager: true })
const routeModuleList: AppRouteModule[] = []

// 加入到路由集合中
Object.keys(modules).forEach((key) => {
  const mod = (modules[key] as any).default || {}
  const modList = Array.isArray(mod) ? [ ...mod ] : [ mod ]
  routeModuleList.push(...modList)
})

export const notFoundRoute: AppRouteModule = {
  path: '/:path(.*)*',
  name: 'NotFound',
  redirect: '/'
}

// 自定义路由
export const routerList: AppRouteModule[] = [
  {
    path: '/user',
    component: UserLayout,
    name: 'UserLayout',
    redirect: '/user/login',
    children: [
      {
        path: '/user/login',
        name: 'Login',
        meta: {
          title: '登录'
        },
        component: () => import('@/pages/user/login/index.vue')
      }
    ]
  },
  {
    path: '/',
    name: '首页',
    component: BasicLayout,
    children: routeModuleList
  },
  notFoundRoute
]
