import presetRemToPx from '@unocss/preset-rem-to-px'
import {
  defineConfig,
  presetAttributify,
  presetIcons,
  presetMini,
  presetUno,
  transformerDirectives,
  transformerVariantGroup
} from 'unocss'

export default defineConfig({
  presets: [
    presetUno,
    presetAttributify,
    presetIcons(),
    // @ts-ignore
    presetRemToPx({
      baseFontSize: 4
    }),
    presetMini()
  ],
  transformers: [
    transformerDirectives({
      applyVariable: [ '--at-apply' ]
    }),
    transformerVariantGroup()
  ],
  shortcuts: [
    {
      'flex-center': 'flex items-center justify-center'
    },
  ],
  rules: [
    [
      /^text-rgba-(.*)$/,
      ([ , str ]) => {
        const regex = /\[([^[\]]*)\]/
        const match = str.match(regex)

        if (match && match.length > 1) {
          const contentInsideBrackets = match[1]
          return {
            color: `rgba(${contentInsideBrackets.split('-').join(',')})`
          }
        } else {
          return {}
        }
      }
    ],
    [
      /^bg-rgba-(.*)$/,
      ([ , str ]) => {
        const regex = /\[([^[\]]*)\]/
        const match = str.match(regex)

        if (match && match.length > 1) {
          const contentInsideBrackets = match[1]
          return {
            'background-color': `rgba(${contentInsideBrackets.split('-').join(',')})`
          }
        } else {
          return {}
        }
      }
    ],
    [
      /^bd-(.*)$/,
      ([, str]) => {
        return {
          'border': `1px solid ${str === 'main' ? 'var(--van-primary-color)' : str === 'error' ? 'var(--van-danger-color)' : `#${str}`}`
        }
      }
    ],
    [
      /^bd-l-(.*)$/,
      ([, str]) => {
        return {
          'border-left': `1px solid ${str === 'main' ? 'rgba(5, 5, 5, 0.06)' : `#${str}`}`
        }
      }
    ],
    [
      /^bd-t-(.*)$/,
      ([, str]) => {
        return {
          'border-top': `1px solid ${str === 'main' ? 'rgba(5, 5, 5, 0.06)' : `#${str}`}`
        }
      }
    ],
    [
      /^bd-b-(.*)$/,
      ([, str]) => {
        return {
          'border-bottom': `1px solid ${str === 'main' ? 'rgba(5, 5, 5, 0.06)' : `#${str}`}`
        }
      }
    ],
    [
      /^text-hidden-(\d+)$/,
      ([ , d ]) => ({
        overflow: 'hidden',
        'text-overflow': 'ellipsis',
        display: '-webkit-box',
        '-webkit-line-clamp': d,
        'line-clamp': d,
        '-webkit-box-orient': 'vertical',
        'word-break': 'break-word'
      })
    ],
    [ 'hidden-none', { opacity: '0', visibility: 'hidden' } ],
    [
      /^flex-main-(\d+)$/,
      ([ , d ]) => ({
        flex: `0 0 ${d}px`
      })
    ],
    [
      /^shrink-(\d+)$/,
      ([ , d ]) => ({
        'flex-shrink': d
      })
    ],
    [ 'text-hex-main', { color: 'var(--gx-primary-color)' } ],
    [ 'text-hex-error', { color: 'var(--gx-color-error)' } ],
    [ 'bg-hex-main', { background: 'var(--gx-primary-color)' } ],
    [ 'word-break-all', { 'word-break': 'break-all' } ],
    [ 'word-break-word', { 'word-break': 'break-word' } ],
    [ 'flex-main', { flex: '1' } ],
    [ 'position-all', { position: 'absolute', top: '0', bottom: '0', left: '0', right: '0' } ],
    [ 'image-event-none', { 'user-select': 'none', 'pointer-events': 'none' } ],
    [
      'position-center',
      {
        left: '50%',
        top: '50%',
        transform: 'translate(-50%, -50%)'
      }
    ],
    [
      'position-center-x',
      {
        left: '50%',
        transform: 'translateX(-50%)'
      }
    ],
    [
      'position-center-y',
      {
        top: '50%',
        transform: 'translateY(-50%)'
      }
    ]
  ]
})
